//  file: ODRBC.H
//
//  TODRadioButton class declaration
//      Defines the interface for owner-drawn radio buttons.
//
// This source code was written by Colin Robertson and, to
// the extent I can claim ownership rights herein, is dedicated to
// the public domain. Use as you see fit. I also disclaim any
// warranty or liability for this code or anything derived from
// it.
//
// Colin Robertson can be reached at:
// CIS: 70550,3306
// Internet: colinr@dsinet.uucp
//

#ifndef __ODRBC_H
#define __ODRBC_H

#ifndef __WINDOWSX_H
#include <windowsx.h>
#endif
#ifndef __OWL_H
#include <owl.h>
#endif
#ifndef __BWCC_H
#include <bwcc.h>
#endif
#ifndef __BRADIO_H
#include <bradio.h>
#endif


//-----------------------------------------------------------------------
//  TODRadioButton class
//
//  Use this class to create owner-drawn radio buttons in your windows
//  and dialogs. As implemented, we use five bitmaps to draw the radio
//  button in various states, but that shouldn't keep you from doing the
//  drawing in any way you see fit. See the implementation code in
//  ODRBC.CPP for more information.
//
//  This class is derived from the Borland-style radio button class; to
//  use it, your project must be linked with BWCC.LIB.
//
 
_CLASSDEF(TODRadioButton)

class _EXPORT TODRadioButton : public TBRadioButton
    {
    enum ResourceOffset
        {
        UpNoFocus = 1000,
        DnFocus = 3000,
        UpFocus = 5000,
        DnNoFocus = 7000,
        Grayed = 9000
        };

    HBITMAP hBtnUp, hBtnDn, hBtnUpF, hBtnDnF, hBtnGray;
    int m_H, m_W;

    void Init( int nId );
public:
    TODRadioButton( PTWindowsObject AParent, int AnId, LPSTR ATitle,
                    int X, int Y, int W, int H, PTGroupBox AGroup,
                    PTModule AModule = NULL )
    : TBRadioButton( AParent, AnId, ATitle, X, Y, W, H, AGroup, AModule )
        {
        // set owner draw attribute for buttons
        Attr.Style = BS_AUTORADIOBUTTON | BBS_OWNERDRAW |
                     WS_CHILD | WS_VISIBLE ;
        Init( AnId );
        Attr.H = m_H; Attr.W = m_W;
        }

    TODRadioButton( PTWindowsObject AParent, int ResourceId, PTGroupBox AGroup,
		    PTModule AModule = NULL )
    : TBRadioButton( AParent, ResourceId, AGroup, AModule )
        { Init( ResourceId ); }

    ~TODRadioButton();

protected:
    virtual void WMDrawItem( RTMessage Msg ) = [WM_FIRST + WM_DRAWITEM];

    };

#endif
