//  file: ODRBTN2.CPP
//
//  Owner-drawn Radio Button Test Application
//      Loosely based on the TRANTEST sample application
//      which came as part of the sample code in BC++3.1w/AF. 
//
// This source code was written by Colin Robertson and, to
// the extent I can claim ownership rights herein, is dedicated to
// the public domain. Use as you see fit. I also disclaim any
// warranty or liability for this code or anything derived from
// it.
//
// Colin Robertson can be reached at:
// CIS: 70550,3306
// Internet: colinr@dsinet.uucp
//
// This project consists of several bitmap files, containing images
// for radio buttons in various states of focus and selection;
// a resource file which includes the bitmaps, the test app's
// menu, and a test dialog with resources including the radio
// buttons to be drawn; the files defining the owner-drawn
// radio button class; this file, which contains the test app
// source; a header file with resource ID definitions; a project
// file, and a makefile for command-line junkies. When built, the
// resulting app will have a menu with a single command ("Test!")
// which will bring up a dialog with three owner-drawn radio
// buttons in a group. If the dialog is dismissed with an OK,
// a message box will come up, indicating the results from the dialog
// selection. This may also be a good example app for the use
// of the TransferStruct facility.
//
// Project options may need to be changed to reflect your
// directory structure; I've assumed you used the default
// directories for your Borland installation, and that this
// project is being built in a directory just off the root of
// the same drive as the Borland installation. If your setup differs
// from this, you will need to change the defaults in the
// Options|Directories dialog, and possibly some of the entries
// in the project itself (such as owl.def).
//

#include <owl.h>
#include <bwcc.h>
#include <edit.h>
#include <string.h>
#include "odrbtn2.h"
#include "odrbc.h"

const MAXNAMELEN = 26;

//----------------------------------------------------------------------
// TTransferStruct defined for use in TODRadioWindow
//

struct TTransferStruct
    {
    BOOL m_fTable;
    BOOL m_fChart;
    BOOL m_fPie;
    char m_szNameEdit[ MAXNAMELEN ];
    };


//----------------------------------------------------------------------
// TODRadioApp: Test Application class definition
//

class TODRadioApp : public TApplication
    {
public:
    TODRadioApp( LPSTR AName, HINSTANCE hInstance, HINSTANCE hPrevInstance,
                  LPSTR lpCmdLine, int nCmdShow)
    : TApplication( AName, hInstance, hPrevInstance, lpCmdLine, nCmdShow ) {};

    virtual void InitMainWindow();
    };


//----------------------------------------------------------------------
// TODRadioWindow: Test Application's main window class definition
//

class TODRadioWindow : public TWindow
    {
public:
    TTransferStruct m_xferBuffer;

    TODRadioWindow(PTWindowsObject AParent, LPSTR ATitle);
    virtual void CMTest(TMessage& Msg) = [CM_FIRST + CM_TEST];
    };


//----------------------------------------------------------------------
// TODRadioDialog: Radio button test dialog class definition
//

class TODRadioDialog : public TDialog
    {
public:
    TODRadioDialog( PTWindowsObject AParent, int ResourceId );
    };


//----------------------------------------------------------------------
// TODRadioWindow ctor
//

TODRadioWindow::TODRadioWindow(
    PTWindowsObject AParent,
    LPSTR ATitle)
: TWindow( AParent, ATitle )
    {
    AssignMenu( ID_MENU );
    memset( &m_xferBuffer, 0x0, sizeof m_xferBuffer );
    m_xferBuffer.m_fTable = TRUE;
    m_xferBuffer.m_fChart = FALSE;
    m_xferBuffer.m_fPie = FALSE;
    }

//----------------------------------------------------------------------
// TODRadioWindow :: CMTest menu handler
//

void TODRadioWindow::CMTest(TMessage&)
    {
    char szLabel[ 255 ];

    if ( GetModule()->ExecDialog( new TODRadioDialog( this, ID_DIALOG )) == IDOK )
        {
        strcpy( szLabel, "Test Dialog Results:\n\n" );
        if ( m_xferBuffer.m_fTable )
            strcat( szLabel, "Table: ");
        else if ( m_xferBuffer.m_fChart )
            strcat( szLabel, "Chart: ");
        else
            strcat( szLabel, "Pie: ");
        strcat( szLabel, m_xferBuffer.m_szNameEdit);
        strcat( szLabel, "\n");
        BWCCMessageBox( HWindow,  szLabel, "Test Dialog Transfer", MB_OK );
        }
    }

//----------------------------------------------------------------------
// TODRadioDialog ctor
//

TODRadioDialog::TODRadioDialog(
    PTWindowsObject AParent,
    int ResourceId )
: TDialog( AParent, ResourceId )
    {
    new TODRadioButton( this, IDB_TABLEBUTTON, NULL );
    new TODRadioButton( this, IDB_CHARTBUTTON, NULL );
    new TODRadioButton( this, IDB_PIEBUTTON, NULL );
    new TEdit( this, ID_NAMEEDIT,
               sizeof(((TODRadioWindow *)Parent)->m_xferBuffer.m_szNameEdit));
    TransferBuffer = (void far*)&(((TODRadioWindow *)Parent)->m_xferBuffer);
    }


//----------------------------------------------------------------------
// TODRadioApp main window implementation
//

void TODRadioApp::InitMainWindow()
    {
    MainWindow = new TODRadioWindow( NULL, "Test OwnerDrawn Radio Buttons");
    }


//----------------------------------------------------------------------
// Main program
//

int PASCAL WinMain(
    HINSTANCE hInstance,
    HINSTANCE hPrevInstance,
    LPSTR lpCmdLine,
    int nCmdShow )
    {
    TODRadioApp ODRadioApp( "ODRadioTest", hInstance, hPrevInstance,
                            lpCmdLine, nCmdShow );
    ODRadioApp.Run();
    return ODRadioApp.Status;
    }
